function [ogroup,glabel,gname,multigroup,maxgroup] = nan_mgrp2idx(groups,rows,sep)
//  Convert multiple grouping variables to index vector
//  Calling Sequence
//  [ogroup,glabel,gname,multigroup,maxgroup] = nan_mgrp2idx(groups,rows,sep)
//  Parameters
//  groups: grouping variable (numeric, string or cell)
//  sep:seperator
//  ogroup: vector of group indices
//  glabel: cell of group labels
//  

[nargout,nargin]=argn(0);

multigroup = (iscell(groups) & size(groups,1)==1) |  (or(type(groups)==[1 4 8]) & ~isvector(groups) & ~isempty(groups));
if (~multigroup)
    [ogroup,gname] = nan_grp2idx(groups);
    maxgroup = size(gname,'*');
    glabel = gname;
else
    
    ngrps = size(groups,2);
    namemat = cell(1,ngrps);

    
    if iscell(groups)
        if ngrps == 0 
            groups=cell(1,1);
            groups.entries(1) = ones(rows,1);
            ngrps = 1;
            namemat = cell(1,ngrps);
        end
        for j=1:ngrps
            [g,gn] = nan_grp2idx(groups(1,j));
            if j==1
                rows = size(g,1);
                grpmat = zeros(rows,ngrps);
            elseif (size(g,1)~=rows)
                error( 'Number of rows must be the same');
            end
            grpmat(:,j) = g;
            namemat(1,j) = gn;
        end
    else
        rows = size(groups,1);
        grpmat = zeros(rows,ngrps);
        for j=1:ngrps
            [g,gn] = nan_grp2idx(groups(:,j));
            grpmat(:,j) = g;
            namemat(1,j) = gn;
        end
    end
    
   
    wasnan = or(isnan(grpmat),2);
    grpmat(wasnan,:) = [];
    [urows,ui,uj] = nan_unique(grpmat,'rows');
    
    
    ogroup = ones(wasnan)*%nan;
    ogroup(~wasnan) = uj;
    gname = cell(size(urows));

    for j=1:ngrps
        gn = namemat(1,j);
        gname(:,j) = gn(urows(:,j));
    end

   
    glabel = cell(size(gname,1),1);
    if (nargin > 2)
        nl = sprintf(sep);
    else
        nl = sprintf('\n');
    end
    fmt = sprintf('%%s%s',nl);
    lnl = length(fmt)-3;       
    for j=1:length(glabel)
        gn = sprintf(fmt, gname(j,:));
        gn($-lnl:$) = [];
        glabel(j,1) = gn;
    end
    maxgroup = size(glabel,'*');
end
endfunction
